@@ -184,9 +184,9 @@ class BaseSwanProcess(object):
     STATUS_RE = '\d\d\d "([a-f0-9\-]+).* (unrouted|erouted);'
     STATUS_NOT_RUNNING_RE = 'Command:.*ipsec.*status.*Exit code: [1|3]$'
     STATUS_IPSEC_SA_ESTABLISHED_RE = (
-        '\d{3} #\d+: "([a-f0-9\-]+).*IPsec SA established.*')
+        '\d{3} #\d+: "([a-f0-9\-]+).*established.*newest IPSEC')
     STATUS_IPSEC_SA_ESTABLISHED_RE2 = (
-        '\d{3} #\d+: "([a-f0-9\-\/x]+).*IPsec SA established.*')
+        '\d{3} #\d+: "([a-f0-9\-\/x]+).*established.*newest IPSEC')
 
     def __init__(self, conf, process_id, vpnservice, namespace):
         self.conf = conf
@@ -279,6 +279,13 @@ class BaseSwanProcess(object):
             {'vpnservice': vpnservice,
              'state_path': self.conf.state_path})
 
+    def _get_rootwrap_config(self):
+        if 'neutron-rootwrap' in cfg.CONF.AGENT.root_helper:
+            rh_tokens = cfg.CONF.AGENT.root_helper.split(' ')
+            if len(rh_tokens) == 3 and os.path.exists(rh_tokens[2]):
+                return rh_tokens[2]
+        return None
+
     @abc.abstractmethod
     def get_status(self):
         pass
